@@ -29,6 +29,14 @@ class JsonPatchBuilder:
         return {'patch': patch} if patch else None
 
 
+class NewResourceBuilder:
+    def __init__(self, audit_log):
+        self.audit_log = audit_log
+
+    def build(self, resource, _payload):
+        return {'resource': resource}
+
+
 class ReadResourceBuilder:
     def __init__(self, audit_log):
         self.audit_log = audit_log
@@ -43,6 +51,7 @@ MODE_BUILDERS = {
     'prev_and_new': OldAndNewBuilder,
     'old_and_new': OldAndNewBuilder,
     'read': ReadResourceBuilder,
+    'create': NewResourceBuilder,
 }
 
 
